@@ -810,7 +810,7 @@ def pbdDict_bisosRoot(
     directory('git/auth/bxRepos')
     directory('git/anon')    
     directory('git/anon/bxRepos')
-    symLink( 'git/bxRepos',  'git/auth/bxRepos' )    
+    symLink('git/bxRepos',  'git/anon/bxRepos')    
     
     directory('control')
     directory('control/bisos')    
@@ -828,7 +828,8 @@ def pbdDict_bisosRoot(
     directory('core')
     # symLink(  'core/bin', 'dist/pip/core/bin')
     # symLink(  'core/input', 'dist/pip/core/input')
-    symLink('core/bsip3', 'git/bxRepos/bisos/bsip3')
+    symLink('core/bsip4', 'git/bxRepos/bisos/bsip4')
+    symLink('core/bpip1', 'git/bxRepos/bisos/bpip')    
     symLink('core/var', 'var/core')
     symLink('core/tmp', 'tmp')
     symLink('core/log', 'log/core')
@@ -837,6 +838,7 @@ def pbdDict_bisosRoot(
 
     directory('apps')
     symLink('apps/bxtex', 'git/bxRepos/bxlcnt/bxtex')
+    symLink('apps/comeega', 'git/bxRepos/bisos/comeega')    
 
     directory('panels')
     directory('panels/bisos')
